@@ -1,5 +1,5 @@
 #define PCI_CONFIG_H
-#define PCI_ARCH_AMD64
+#define PCI_ARCH_SPARC64
 #define PCI_OS_OPENBSD
 #define PCI_HAVE_PM_OBSD_DEVICE
 #define PCI_PATH_OBSD_DEVICE "/dev/pci"
@@ -9,4 +9,4 @@
 #define PCI_PATH_IDS_DIR "/usr/local/share"
 #define PCI_USE_DNS
 #define PCI_ID_DOMAIN "pci.id.ucw.cz"
-#define PCILIB_VERSION "3.1.9"
+#define PCILIB_VERSION "3.2.1"
